#!/bin/bash
#########################################
# Written by: Florent Maillefaud
# Contact at: florent@restezconnectes.fr
# Release 0.1
#########################################

###############################################################################
#                                            Coloration des echo              #
###############################################################################
function cecho {
    while [ "$1" ]; do
        case "$1" in 
            -red)           color="\033[31;01m" ;;
            -green)         color="\033[32;01m" ;;
            -yellow)        color="\033[33;01m" ;;
            -blue)          color="\033[34;01m" ;;
            -n)             one_line=1;   shift ; continue ;;
            *)              echo -n "$1"; shift ; continue ;;
        esac

        shift
        echo -en "$color"
        echo -en "$1"
        echo -en "\033[00m"
        shift

    done
    if [ ! $one_line ]; then
        echo
    fi
}

# Define
#-----------------------------------------------------------------------------

# le root du dossier www
CONF_DOCUMENT_ROOT="/var/vhosts/"
CONF_BASEPATH="/www/"
# Chemin vers le fichier hosts
CONF_HOSTS_FILE="/etc/hosts"
# Accès à la base de données
CONF_DB_HOST="localhost"
CONF_DB_USER="root"
CONF_DB_PASS="boss"

# Functions
#-----------------------------------------------------------------------------

last_command() {
        EXIT_V="$?"
        case $EXIT_V in
                0) 
                cecho -green " ✓ Voilà c'est fait !"              
                ;;
                1)
                cecho -red " ✗ Oupss ! J'ai échoué..."
                                
                ;;
        esac        
}

display_ban() {
 clear
 echo 
 cecho -green " ################################################################################"
 cecho -green " #                               Welcome $USER                                   #"
 cecho -green " #                              delete vhosts                                   #"
 cecho -green " ################################################################################"
 echo 
}

display_separator() {
 echo        
 echo " - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - "
 echo
}


test_root() {
 if [ $EUID -ne 0 ]; then
  cecho -red " Le script doit être lancé en root" 1>&2
  exit 1
 fi
}

# Start script
#-----------------------------------------------------------------------------

test_root
display_ban

echo -n " ✎ Nom du site à supprimer : "
read site_name

echo
cecho -yellow " ⚠ ATTENTION : le site $site_name.local.sites.fr sera supprimé ! "
echo

pathToVhost="/etc/apache2/sites-available/${site_name}.conf"
cecho -blue " Voulez-vous continuer ? Y/n"

# edit hosts file
read inputAlias
if [ "$inputAlias" = "y" -o "$inputAlias" = "Y"  -o -z "$inputAlias" ]
then
	echo -n " ☛ Suppression de la ligne dans le fichier hosts en cours... "
	echo
	sed -i '/'${site_name}'/d' ${CONF_HOSTS_FILE}
fi
last_command
display_separator
sleep 2

# a2dissite
cecho -yellow " ☛ Désactive le vhost ${site_name}"
sudo a2dissite ${site_name}.conf
last_command
display_separator

sleep 2
# Supprime le fichier conf
cecho -yellow " ☛ Supprime le fichier : /etc/apache2/site-available/${site_name}.conf"
sudo rm ${pathToVhost}
last_command
display_separator

sleep 2
# Supprime le répertoire
echo " ☛ Supprime le répertoire : ${site_name}.local.sites.fr"
sudo rm -R '/var/vhosts/'${site_name}'.local.sites.fr'
last_command
display_separator

# Supprime base de données
cecho -yellow " ☛ Supprime la base de données : ${site_name}"
Q1="DROP DATABASE \`${site_name}\`;"
mysql -u "${CONF_DB_USER}" --password="${CONF_DB_PASS}" -e "$Q1"
last_command
display_separator

sleep 2
# restart apache
cecho -yellow " ☛ Apache restart : "
apachectl graceful
last_command
display_separator
echo
echo '  ㋡  '
sleep 2


