#!/bin/bash
#############################################
# Comment utiliser ?
# 1 - Changez la configuration par defaut ci-dessous pour correspondre à vos besoins
# 2 - ensuite via un terminal : 
#       ./site-factory.sh ou ./site-factory.sh www.monsite.com
#############################################


###############################################################################
#                                            Coloration des echo                                   #
###############################################################################
function cecho {
    while [ "$1" ]; do
        case "$1" in 
            -red)           color="\033[31;01m" ;;
            -green)         color="\033[32;01m" ;;
            -yellow)        color="\033[33;01m" ;;
            -blue)          color="\033[34;01m" ;;
            -n)             one_line=1;   shift ; continue ;;
            *)              echo -n "$1"; shift ; continue ;;
        esac

        shift
        echo -en "$color"
        echo -en "$1"
        echo -en "\033[00m"
        shift

    done
    if [ ! $one_line ]; then
        echo
    fi
}

#############################################
# CONFIGURATION
#############################################

# le root du dossier www
CONF_DOCUMENT_ROOT="/var/vhosts/"

# si dans le dossier du domaine on veux un sous dossier qui soit le basepath
# ex : /media/vhosts/monsite.com/ => BASEPATH="/"
# ex : /media/vhosts/monsite.com/httpdocs => BASEPATH="/httpdocs/"
CONF_BASEPATH="/www/"

# Doit on aussi créer les dossiers logs, db.. dans le dossier
# ex : /media/vhosts/monsite.com/db
# ex : /media/vhosts/monsite.com/www # crée automatiquement à l'aide du parametre de configuration CONF_BASEPATH plus haut
CONF_CREATE_SPECIAL_FOLDERS=$true #valeurs possible $false ou $true

#declare -a CONF_SPECIALS_FOLDERS=("sh" "db" "docs")

# Doit on créer un dossier pour contenir les fichiers de log ?
CONF_CREATE_LOG_FOLDER=$true #valeurs possible $false ou $true

# le nom du dossier contenant les fichiers de log
# ex : /media/vhosts/monsite.com/logs avec la valeur logs
CONF_CREATE_LOG_FOLDER_NAME="logs"

# Chemin vers le fichier hosts
CONF_HOSTS_FILE="/etc/hosts"

# extention utilisé pour les sites en developpement
CONF_DEV_EXT="dev"

# Accès à la base de données
CONF_DB_HOST="localhost"
CONF_DB_USER="root"
CONF_DB_PASS="boss"

last_command() {
        EXIT_V="$?"
        case $EXIT_V in
                0) 
                cecho -green " ✓ Voilà c'est fait !"                
                ;;
                1)
                cecho -red " ✗ Oupss ! J'ai échoué..."
                exit                
                ;;
        esac        
}

test_root() {
 if [ $EUID -ne 0 ]; then
  cecho -red "Le script doit être lancé en root" 1>&2
  exit 1
 fi
}
display_ban() {
 clear
 echo 
 cecho -green "################################################################################"
 cecho -green "#                               Welcome $USER                                   #"
 cecho -green "#                              vhosts generator                                #"
 cecho -green "################################################################################"
 echo 
}
display_separator() {
 echo        
 echo "################################################################################"
 echo
}

clear
test_root
#############################################
#PARTIE 1 RECUPERATION DE L'URL DU SITE
#############################################

display_ban
echo -n " ✎ Choisir un nom pour le site  : "
read domaine

echo
cecho -blue " ☛ Le site sera configuré tel quel : "
echo
echo "  ➠ Domaine : "$domaine".local.sites.fr"
echo "  ➠ Ce repertoire sera créé : /var/vhosts/"$domaine".local.sites.fr"

domaineDev=${domaine}".local.sites.fr"
pathToVhost="/etc/apache2/sites-available/"${domaine}".conf"
pathIndexFile=${CONF_DOCUMENT_ROOT}${domaineDev}${CONF_BASEPATH}"/index.php"

#echo "URL du site en developpement : ${domaineDev}"
echo "  ➠ Le vhost sera créé et situé ici : "${pathToVhost}
echo

sleep 3

# création du vhost
cecho -blue " ✓ Voulez-vous continuer ? Y/n"
read inputAlias
if [ "$inputAlias" = "y" -o "$inputAlias" = "Y"  -o -z "$inputAlias" ]
then
	clear
	display_ban     
	cecho -blue " ✎ Veuillez renseigner le dossier de travail en absolu."
        echo "  ➠ si vide : ${CONF_DOCUMENT_ROOT}${domaineDev}${CONF_BASEPATH}"
        read www_folder
        if [ -z "$www_folder" ]
        then
                www_folder="${CONF_DOCUMENT_ROOT}${domaineDev}${CONF_BASEPATH}"
        fi
        sudo mkdir -p ${www_folder}
        
        if [ CONF_CREATE_LOG_FOLDER ]
        then
                echo "creation dossier contenant les fichiers de log ${CONF_DOCUMENT_ROOT}${domaineDev}/${CONF_CREATE_LOG_FOLDER_NAME}"
                sudo mkdir -p ${CONF_DOCUMENT_ROOT}${domaineDev}/${CONF_CREATE_LOG_FOLDER_NAME}
                sudo mkdir -p ${CONF_DOCUMENT_ROOT}${domaineDev}/${CONF_CREATE_CONF_FOLDER_NAME}
                sudo touch ${CONF_DOCUMENT_ROOT}${domaineDev}/${CONF_CREATE_LOG_FOLDER_NAME}/error.log
                sudo touch ${CONF_DOCUMENT_ROOT}${domaineDev}/${CONF_CREATE_LOG_FOLDER_NAME}/access.log
        fi
fi

last_command
sleep 2
clear
display_ban

#############################################
# CREATION VHOST APACHE 2.4
#############################################
cecho -blue " ✓ Voulez vous créer Le Virtual Host Apache 2.4 ? Y/n"
read inputAlias
if [ "$inputAlias" = "y" -o "$inputAlias" = "Y"  -o -z "$inputAlias" ]
then
        echo " ☛  Creation du Vhost Apache 2.4"
        ServerAlias=$false
        if [ flag_www ]
        then
                echo
		cecho -blue " ✓ Doit-on créer le ServerAlias avec WWW ? www.${domaineDev} Y/n"
                read inputAlias
                if [ "$inputAlias" = "y" -o "$inputAlias" = "Y" -o -z "$inputAlias" ]
                then
                        ServerAlias=$true
                fi
        fi
        echo " ☛ Voici le résumé du vhost : "
        echo "    ➠ situé : ${pathToVhost}"
        echo "    ➠ ServerName : ${domaineDev}"
        if [ ServerAlias ]
        then
                echo "    ➠ ServerAlias : www.${domaineDev}"
        fi
        echo "    ➠ directory : ${www_folder}"
        sudo touch ${pathToVhost}
        sudo chown $USER ${pathToVhost}
        sudo echo -e "<VirtualHost *:80>" >> ${pathToVhost}
	sudo echo -e "\t#nom de domaine" ${domaineDev} >> ${pathToVhost}
        sudo echo -e "\tServerName ${domaineDev}" >> ${pathToVhost}


        if [ ServerAlias ]
        then
		sudo echo -e "\t#on accepte aussi le www" >> ${pathToVhost}
                sudo echo -e "\tServerAlias www.${domaineDev}" >> ${pathToVhost}
        fi

        if [ CONF_CREATE_LOG_FOLDER ]
       	then
		sudo echo -e "\t#logs d'erreur" >> ${pathToVhost}
           	sudo echo -e "\tErrorLog ${CONF_DOCUMENT_ROOT}${domaineDev}/${CONF_CREATE_LOG_FOLDER_NAME}/error.log" >> ${pathToVhost}
		sudo echo -e "\t#logs de connexion" >> ${pathToVhost}
            	sudo echo -e "\tCustomLog ${CONF_DOCUMENT_ROOT}${domaineDev}/${CONF_CREATE_LOG_FOLDER_NAME}/access.log common" >> ${pathToVhost}
       	fi

	sudo echo -e "\t#Définition de la racine des sources php" >> ${pathToVhost}
        sudo echo -e "\tDocumentRoot \"${www_folder}\"" >> ${pathToVhost}

        
        sudo echo -e "\t<directory ${www_folder}>" >> ${pathToVhost}
        sudo echo -e "\t\tOptions -Indexes +FollowSymLinks +MultiViews" >> ${pathToVhost}
        sudo echo -e "\t\tAllowOverride All" >> ${pathToVhost}
        sudo echo -e "\t\tRequire all granted" >> ${pathToVhost}
        sudo echo -e "\t</Directory>" >> ${pathToVhost}
        sudo echo -e "</VirtualHost>" >> ${pathToVhost}
fi

last_command
sleep 2
clear
display_ban

#############################################
# AJOUT AU FICHIER HOSTS
#############################################

cecho -blue "  ✓ Ajouter une entrée au fichier HOSTS ? Y/n"
read inputAlias
if [ "$inputAlias" = "y" -o "$inputAlias" = "Y" -o -z "$inputAlias" ]
then

        sudo echo -e "127.0.0.1\t${domaineDev}" >> ${CONF_HOSTS_FILE}
		if [ flag_www ]
		then
        	sudo echo -e "127.0.0.1\twww.${domaineDev}" >> ${CONF_HOSTS_FILE}

		fi
fi

last_command
sleep 2
clear
display_ban


#############################################
# CREATION BASE DE DONNEES
#############################################

cecho -blue " ✓ Voulez vous créer une base de donnée ? Y/n"
read inputAlias
if [ "$inputAlias" = "y" -o "$inputAlias" = "Y" -o -z "$inputAlias" ]
then
        echo "  ✎ Nom de la base de données (si vide : ${domaine})"
        read db_name
        if [ -z "$db_name" ]
        then
                db_name="$domaine"
        fi
        echo " ✎ Nom de la base de données : $db_name"

        Q1="CREATE DATABASE \`$db_name\`;"
        mysql -u "${CONF_DB_USER}" --password="${CONF_DB_PASS}" -e "$Q1"
fi

last_command
sleep 2
clear
display_ban


cecho -blue " ✓ Activation du VirtualHost"


sudo a2ensite ${domaine}.conf
sudo service apache2 restart

last_command
sleep 2
clear
display_ban


cecho -blue " ☛ Changement des droits du dossier ${www_folder}"
echo " ☛ Changements faits sur : ${CONF_DOCUMENT_ROOT}${domaineDev}"
sudo touch ${pathIndexFile}
sudo echo -e "<?php echo 'Votre nouveau site ${domaineDev} est en place !'; ?>" >> ${pathIndexFile}

sudo chown $USER ${CONF_DOCUMENT_ROOT}${domaineDev} -R
sudo chgrp www-data ${CONF_DOCUMENT_ROOT}${domaineDev} -R
sudo chmod ug+wrx ${CONF_DOCUMENT_ROOT}${domaineDev} -R

last_command
sleep 2
clear

# restart apache
display_ban
echo -n " ☛ Apache restart                   : "
apachectl graceful
last_command
sleep 2

# Finish
clear
display_ban
echo
cecho -blue " ㋡ Votre site est maintenant prêt... à vous de jouer !"
echo
